
import logging,os


from dataset import save_nc, get_outfile, to_weekly, to_monthly
from analogs import analogs_seas_hcst,analogs_seas_fcst
from tools import cut_domain

def apply_downscale(exp,srcobs,targetobs,target_var,region, conf):
    
    outdir,outfile = get_outfile(exp,conf.outdir)
    sys = conf.arch.get_system(conf.exp_sys,conf.temp_freq)

    if not os.path.isfile(outdir+outfile) or conf.overwrite:
        exp = exp.interp_like(srcobs[target_var].isel(time=0, drop=True), method="nearest")
        logging.info('cutting domain and loading exp data in memory...')    

        exp = cut_domain(exp,conf.regions[region]).load()
        logging.info('exp load completed...')    

        logging.info('Applying analogs method')

        if exp.attrs['system-type'] == "hcst":

            downs = analogs_seas_hcst(exp[target_var],
                         srcobs[target_var],
                         targetobs[target_var],
                         )
        else:
            downs = analogs_seas_fcst(exp[target_var],
                                      srcobs[target_var],
                                      targetobs[target_var])

        logging.info('exporting to .nc')
        downs.attrs = exp.attrs
        downs["time_bnds"] = exp.time_bnds
        
        save_nc(downs,conf.outdir)

        if sys['type'] == "seasonal":
            save_nc(to_monthly(downs),conf.outdir)
        elif sys['type'] == "subseasonal":
            save_nc(to_weekly(downs),conf.outdir)
            
    else:
        logging.warning(f'file {outdir+outfile} already exists, skipping computation')

